@@ -28,8 +28,8 @@ import gobject
 import vte
 import gconf
 import gettext
-import gnomevfs
 import os
+import gio
 from gpdefs import *
 
 try:
@@ -50,17 +50,16 @@ class GeditTerminal(gtk.HBox):
     }
 
     GCONF_PROFILE_DIR = "/apps/gnome-terminal/profiles/Default"
-    
+
     defaults = {
         'allow_bold'            : True,
         'audible_bell'          : False,
         'background'            : None,
-        'background_color'      : '#000000',
         'backspace_binding'     : 'ascii-del',
-        'cursor_blinks'         : False,
+        'cursor_blink_mode'     : vte.CURSOR_BLINK_SYSTEM,
+        'cursor_shape'          : vte.CURSOR_SHAPE_BLOCK,
         'emulation'             : 'xterm',
         'font_name'             : 'Monospace 10',
-        'foreground_color'      : '#AAAAAA',
         'scroll_on_keystroke'   : False,
         'scroll_on_output'      : False,
         'scrollback_lines'      : 100,
@@ -87,7 +86,9 @@ class GeditTerminal(gtk.HBox):
         
         gconf_client.notify_add(self.GCONF_PROFILE_DIR,
                                 self.on_gconf_notification)
-        
+
+        # we need to reconf colors if the style changes
+        self._vte.connect("style-set", lambda term, oldstyle: self.reconfigure_vte())
         self._vte.connect("key-press-event", self.on_vte_key_press)
         self._vte.connect("button-press-event", self.on_vte_button_press)
         self._vte.connect("popup-menu", self.on_vte_popup_menu)
@@ -110,26 +111,43 @@ class GeditTerminal(gtk.HBox):
             pass
 
         # colors
-        fg_color = gconf_get_str(self.GCONF_PROFILE_DIR + "/foreground_color",
-                                 self.defaults['foreground_color'])
-        bg_color = gconf_get_str(self.GCONF_PROFILE_DIR + "/background_color",
-                                 self.defaults['background_color'])
-        self._vte.set_colors(gtk.gdk.color_parse (fg_color),
-                             gtk.gdk.color_parse (bg_color),
-                             [])
+        self._vte.ensure_style()
+        style = self._vte.get_style()
+        fg = style.text[gtk.STATE_NORMAL]
+        bg = style.base[gtk.STATE_NORMAL]
+
+        if not gconf_get_bool(self.GCONF_PROFILE_DIR + "/use_theme_colors"):
+            fg_color = gconf_get_str(self.GCONF_PROFILE_DIR + "/foreground_color", None)
+            if (fg_color):
+                fg = gtk.gdk.color_parse (fg_color)
+            bg_color = gconf_get_str(self.GCONF_PROFILE_DIR + "/background_color", None)
+            if (bg_color):
+                bg = gtk.gdk.color_parse (bg_color)
+        self._vte.set_colors(fg, bg, [])
 
         # cursor blink
         blink_mode = gconf_get_str(self.GCONF_PROFILE_DIR + "/cursor_blink_mode")
         if blink_mode.lower() == "system":
-            blink = gconf_get_bool("/desktop/gnome/interface/cursor_blink",
-                                   self.defaults['cursor_blinks'])
+            blink = vte.CURSOR_BLINK_SYSTEM
         elif blink_mode.lower() == "on":
-            blink = True
+            blink = vte.CURSOR_BLINK_ON
         elif blink_mode.lower() == "off":
-            blink = False
+            blink = vte.CURSOR_BLINK_OFF
         else:
-            blink = self.defaults['cursor_blinks']
-        self._vte.set_cursor_blinks(blink)
+            blink = self.defaults['cursor_blink_mode']
+        self._vte.set_cursor_blink_mode(blink)
+
+        # cursor shape
+        cursor_shape = gconf_get_str(self.GCONF_PROFILE_DIR + "/cursor_shape")
+        if cursor_shape.lower() == "block":
+            shape = vte.CURSOR_SHAPE_BLOCK
+        elif cursor_shape.lower() == "ibeam":
+            shape = vte.CURSOR_SHAPE_IBEAM
+        elif cursor_shape.lower() == "underline":
+            shape = vte.CURSOR_SHAPE_UNDERLINE
+        else:
+            shape = self.defaults['cursor_shape']
+        self._vte.set_cursor_shape(shape)
 
         self._vte.set_audible_bell(not gconf_get_bool(self.GCONF_PROFILE_DIR + "/silent_bell",
                                                       not self.defaults['audible_bell']))
@@ -232,7 +250,9 @@ class TerminalWindowHelper(object):
             return None
         uri = doc.get_uri()
         if uri is not None and gedit.utils.uri_has_file_scheme(uri):
-            return os.path.dirname(gnomevfs.get_local_path_from_uri(uri))
+            gfile = gio.File(uri)
+            directory = gfile.get_parent()
+            return os.path.dirname(directory.get_path())
         return None
 
     def on_panel_populate_popup(self, panel, menu):
